@@ -8,7 +8,8 @@ import numpy as np
 import scipy.sparse as sp
 from gensim import corpora
 
-from Orange.data import Table, Domain, ContinuousVariable, DiscreteVariable
+from Orange.data import ContinuousVariable, DiscreteVariable, \
+    Domain, RowInstance, Table
 from orangecontrib.text.vectorization import BowVectorizer
 
 
@@ -37,7 +38,8 @@ class Corpus(Table):
         """Bypass Table.__new__."""
         return object.__new__(cls)
 
-    def __init__(self, domain=None, X=None, Y=None, metas=None, W=None, text_features=None, ids=None):
+    def __init__(self, domain=None, X=None, Y=None, metas=None, W=None,
+                 text_features=None, ids=None):
         """
         Args:
             domain (Orange.data.Domain): the domain for this Corpus
@@ -51,7 +53,7 @@ class Corpus(Table):
         """
         n_doc = _check_arrays(X, Y, metas)
 
-        self.X = X if X is not None and X.size else sp.csr_matrix((n_doc, 0))   # prefer sparse (BoW compute values)
+        self.X = X if X is not None else sp.csr_matrix((n_doc, 0))   # prefer sparse (BoW compute values)
         self.Y = Y if Y is not None else np.zeros((n_doc, 0))
         self.metas = metas if metas is not None else np.zeros((n_doc, 0))
         self.W = W if W is not None else np.zeros((n_doc, 0))
@@ -110,6 +112,22 @@ class Corpus(Table):
             include_feats.append(first)
         self.set_text_features(include_feats)
 
+    def extend(self, instances):
+        if self.domain != instances.domain:
+            raise NotImplementedError(
+                'Extending corpora with different domains is not supported.')
+        super().extend(instances)
+        if self._tokens is None or instances._tokens is None:
+            self._tokens = None
+        else:
+            self._tokens = np.append(self._tokens, instances._tokens)
+        self._dictionary = corpora.Dictionary(self._tokens)
+        if self.pos_tags is None or instances.pos_tags is None:
+            self.pos_tags = None
+        else:
+            self.pos_tags = np.append(self.pos_tags, instances.pos_tags)
+        self._ngrams_corpus = None  # Todo: extend instead of reset
+
     def extend_corpus(self, metadata, Y):
         """
         Append documents to corpus.
@@ -164,6 +182,8 @@ class Corpus(Table):
                 var = DiscreteVariable(f, values=values, compute_value=cv)
             else:
                 var = ContinuousVariable(f, compute_value=cv)
+            if cv is not None:  # set original variable for cv
+                cv.variable = var
             if isinstance(var_attrs, dict):
                 var.attributes.update(var_attrs)
             new_attr += (var, )
@@ -362,7 +382,8 @@ class Corpus(Table):
 
     def __getitem__(self, key):
         c = super().__getitem__(key)
-        Corpus.retain_preprocessing(self, c, key)
+        if isinstance(c, (Corpus, RowInstance)):
+            Corpus.retain_preprocessing(self, c, key)
         return c
 
     @classmethod
@@ -384,7 +405,10 @@ class Corpus(Table):
                 filename = abs_path
 
         table = Table.from_file(filename)
-        return cls(table.domain, table.X, table.Y, table.metas, table.W)
+        X = table.X
+        if not sp.issparse(X) and X.size == 0:
+            X = sp.csr_matrix(X)        # prefer sparse (BoW compute values)
+        return cls(table.domain, X, table.Y, table.metas, table.W)
 
     @staticmethod
     def retain_preprocessing(orig, new, key=...):
