@@ -9,13 +9,11 @@ class BaseVectorizer:
 
     def transform(self, corpus, copy=True, source_dict=None):
         """Transforms a corpus to a new one with additional attributes. """
+        if not (len(corpus.dictionary) or source_dict) or not len(corpus):
+            return corpus
         if copy:
             corpus = corpus.copy()
-
-        if not len(corpus.dictionary):
-            return corpus
-        else:
-            return self._transform(corpus, source_dict)
+        return self._transform(corpus, source_dict)
 
     def _transform(self, corpus, source_dict):
         raise NotImplementedError
@@ -25,11 +23,20 @@ class BaseVectorizer:
         raise NotImplementedError
 
     @staticmethod
-    def add_features(corpus, X, dictionary, compute_values=None):
+    def add_features(corpus, X, dictionary, compute_values=None, var_attrs=None):
         order = np.argsort([dictionary[i] for i in range(len(dictionary))])
-        compute_values = np.array(compute_values)[order]
+        if compute_values is not None:
+            compute_values = np.array(compute_values)[order]
+
+        variable_attrs = {
+            'hidden': True,
+            'skip-normalization': True,
+        }
+        if isinstance(var_attrs, dict):
+            variable_attrs.update(var_attrs)
+
         corpus.extend_attributes(X[:, order],
                                  feature_names=(dictionary[i] for i in order),
-                                 var_attrs={'hidden': True, 'skip-normalization': True},
+                                 var_attrs=variable_attrs,
                                  compute_values=compute_values)
         corpus.ngrams_corpus = matutils.Sparse2Corpus(X.T)
